
/**
 * Dependencies
 */
var _       = require('lodash');
var fs      = require('vinyl-fs');
var map     = require('map-stream');
var path    = require('path');
var q       = require('q');

/**
 * Local dependencies
 */
var mm = require('./mightymite');
var util = require('./utilities');

/**
 * Adds pages to mm.pages data store
 */
module.exports.init = function() {

    var def = q.defer();

    mm.pages = {};

    // Page file source
    var src = path.resolve(mm.config.pagesDir, '**/*.' + util.globFromArray(mm.config.templateTypes) + '');

    fs.src(src)
        .pipe(map(function(file, callback) {

            // Add page to mm.pages
            addPage(file, callback);
        }))
        .on('end', function() {
            def.resolve();
        });

    return def.promise;
};

/**
 * Add page to mm.pages
 */
var addPage = function(file, callback) {

    var contents = util.parseTemplate(file);

    var atts = {
        name:   util.getName(file),
        ext:    util.getExtension(file),
        path:   util.getPath(file, mm.config.pagesDir),
        root:   util.getRoot(file, mm.config.pagesDir),
    };

    atts.attributes = contents.attributes;
    atts.body = contents.body;

    mm.pages[atts.path] = atts;

    callback();
};
